const express = require('express');
const router = express.Router();
const config = require('../config/database');
const Lead = require('../models/lead');
const FollowupLog = require('../models/followuplog');
const Remainder = require('../models/remainder');
const passport = require('passport');
const User = require('../models/user');
const _ = require('lodash');
const csv = require("fast-csv");
const fs = require("fs");
const formidable = require('formidable');

router.post(
  '/update-new-lead',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    Lead.getLeadById(req.body._id, (err, lead) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'error occured', err: err });
      } else {
        if (lead) {
          lead.name = req.body.name;
          lead.email = req.body.email;
          lead.mobile = req.body.mobile;
          lead.wanumber = req.body.wanumber;
          lead.city = req.body.city;
          lead.pcity = req.body.pcity;
          lead.source = req.body.source;
          lead.purpose = req.body.purpose;
          lead.package = req.body.package;
          lead.allotedTo = req.body.allotedTo;
          lead.updatedBy = req.body.updatedBy;
          Lead.addNewLead(lead, (err, lead) => {
            if (err) {
              res.status(200).json({
                success: false,
                msg: 'Failed to edit lead',
                err: JSON.stringify(err)
              });
              return;
            } else {
              res.status(200).json({
                success: true,
                msg: 'Lead edit successful.',
                lead: lead
              });
            }
          });
        } else {
          res.status(200).json({ success: false, msg: 'Lead not found' });
        }
      }
    });
  }
);

router.post(
  '/edit-new-lead',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    Lead.getLeadById(req.body.username, (err, lead) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'error occured', err: err });
      } else {
        if (lead) {
          lead.name = req.body.name;
          (lead.DOB = req.body.DOB),
            (lead.email = req.body.email),
            (lead.mobile = req.body.mobile);
          lead.city = req.body.mobile;
          lead.state = req.body.state;
          lead.gender = req.body.gender;
          lead.updatedBy = req.body.updatedBy;
          Lead.addNewLead(lead, (err, lead) => {
            if (err) {
              res.status(200).json({
                success: false,
                msg: 'Failed to edit lead',
                err: JSON.stringify(err)
              });
              return;
            } else {
              res.status(200).json({
                success: true,
                msg: 'Lead edit successful.',
                lead: lead
              });
            }
          });
        } else {
          res.status(200).json({ success: false, msg: 'Lead not found' });
        }
      }
    });
  }
);

router.post(
  '/upload-bulk-load',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    let error = false;
    Lead.insertArrayofLeads(req.body.newUsers, (err, leads) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'Error occured', err: err });
      } else {
        res
          .status(200)
          .json({ success: true, msg: 'upload successful', leads: leads });
      }
    });
    // for (let i = 0; i < req.body.newUsers.length; i++) {
    //   let newLead = new Lead({
    //     name: req.body.newUsers[i].name,
    //     gender: req.body.newUsers[i].gender,
    //     mobile: req.body.newUsers[i].mobile,
    //     city: req.body.newUsers[i].city,
    //     state: req.body.newUsers[i].state,
    //     createdBy: req.body.newUsers[i].createdBy
    //   });

    //   Lead.addNewLead(newLead, (err, lead) => {
    //     if (err) {
    //       res.status(200).json({
    //         success: false,
    //         msg: 'Failed to create new lead',
    //         err: JSON.stringify(err)
    //       });
    //       return;
    //     } else {
    //       if (req.body.newUsers.length - 1 === i) {
    //         setTimeout(() => {
    //           res.status(201).json({
    //             success: true,
    //             msg: 'Leads added'
    //           });
    //         }, 1000);
    //       }
    //     }
    //   });
    // }
  }
);

router.post(
  '/createNewLead',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    let newLead = new Lead({
      name: req.body.name,
      city: req.body.city,
      pcity: req.body.pcity,
      email: req.body.email,
      gender: req.body.gender,
      mobile: req.body.mobile,
      wanumber: req.body.wanumber,
      source: req.body.source,
      purpose: req.body.purpose,
      createdBy: req.body.user,
      allotedTo: req.body.allotedTo
    });

    // User.getCounsellors((err, counsellors) => {
    //   if (err) {
    //     res
    //       .status(200)
    //       .json({ success: false, msg: 'error occured', err: err });
    //   } else {
    //     for (let i = 0; i < counsellors.length; i++) {
    //       if (_.includes(counsellors[i].cities, newLead.city)) {
    //         counsellors[i].leads.push(newLead);
    //         newLead.counsellor = JSON.stringify(counsellors[i]);
    //         break;
    //       }
    //     }
    //   }
    // });

    Lead.addNewLead(newLead, (err, newLead) => {
      if (err) {
        res.status(200).json({
          success: false,
          msg: 'Failed to create new lead',
          err: JSON.stringify(err)
        });
      } else {
        res
          .status(201)
          .json({ success: true, lead: newLead, msg: 'lead created' });
      }
    });
  }
);

router.get(
  '/getAllLeads',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    Lead.getLeads((err, leads) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'Failed to fetch all leads', err: err });
      } else {
        res
          .status(200)
          .json({ success: true, msg: 'All leads are fetched', leads: leads });
      }
    });
  }
);
router.get(
  '/getAllLeads/:username',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    Lead.getLeadsByUser(req.params.username, (err, leads) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'Failed to fetch all leads', err: err });
      } else {
        res
          .status(200)
          .json({ success: true, msg: 'All leads are fetched', leads: leads });
      }
    });
  }
);

router.post(
  '/getLeadById',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    Lead.getLeadById(req.body.userId, (err, lead) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'Failed to fetch lead', err: err });
      } else {
        res
          .status(200)
          .json({ success: true, msg: 'lead fetched', lead: lead });
      }
    });
  }
);

router.post(
  '/addFollowUp',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    let followup = req.body.followupdata;
    let _id = req.body.userId;
    // // console.log(followup);
    // // console.log(req.body);
    // // console.log(_id);
    Lead.getLeadById(_id, (err, lead) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'Failed to add Followup', err: err });
      } else {
        if (lead.followup) {
          lead.followup.push(followup);
        } else {
          lead.followup = [];
          lead.followup.push(followup);
        }
        // // console.log(lead);
        lead.updatedAt = Date.now();
        Lead.addNewLead(lead, (err, updatedlead) => {
          if (err) {
            res.status(200).json({
              success: false,
              msg: 'Failed to add followup',
              err: err
            });
          } else {
            // // console.log(updatedlead);
            let NewLog = new FollowupLog({
              followupof: req.body.followupof,
              followupby: req.body.followupby,
              followuptype: req.body.followuptype,
              remark: req.body.remark
            });
            // // console.log(NewLog);
            FollowupLog.addLog(NewLog, (err, log) => {
              if (err) {
                res.status(200).json({
                  success: false,
                  msg: 'Failed to add newlog',
                  err: err
                });
              } else {
                if (req.body.followupdata.dueDate != 'undefined') {
                  let newRemainder = new Remainder({
                    alarmDate: req.body.followupdata.dueDate,
                    alarmForLead: req.body.followupof,
                    alarmSetBy: req.body.followupby
                  });
                  // // console.log(newRemainder);
                  Remainder.addRemainder(newRemainder, (err, remainder) => {
                    if (err) {
                      res.status(200).json({
                        success: false,
                        msg: 'error occured',
                        err: err
                      });
                    } else {
                      // // console.log(remainder);
                      res.status(200).json({
                        success: true,
                        msg: 'Followup added successfully',
                        lead: updatedlead
                      });
                    }
                  });
                }
              }
            });
          }
        });
      }
    });
  }
);

router.post(
  '/sendAddress',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    Lead.getLeadById(req.body.userId, (err, lead) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'failed to found lead', err: err });
      } else {
        if (lead) {
          lead.sendAddress.push(req.body.sendAddress);
          Lead.addNewLead(lead, (err, lead) => {
            if (err) {
              res.status(200).json({
                success: false,
                msg: 'failed to add address in array',
                err: err
              });
            } else {
              res
                .status(200)
                .json({ success: true, msg: 'Address added', lead: lead });
            }
          });
        } else {
          res
            .status(200)
            .json({ success: false, msg: 'failed to found lead', err: err });
        }
      }
    });
  }
);

router.post(
  '/sendMsg',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    Lead.getLeadById(req.body.userId, (err, lead) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'failed to found lead', err: err });
      } else {
        if (lead) {
          lead.messages.push(req.body.msg);
          Lead.addNewLead(lead, (err, lead) => {
            if (err) {
              res.status(200).json({
                success: false,
                msg: 'failed to add address in array',
                err: err
              });
            } else {
              res
                .status(200)
                .json({ success: true, msg: 'Address added', lead: lead });
            }
          });
        } else {
          res
            .status(200)
            .json({ success: false, msg: 'failed to found lead', err: err });
        }
      }
    });
  }
);

// getting members
router.get(
  '/getMembers',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    membersList = [];
    Lead.getLeads((err, leads) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'error occured', err: err });
      } else {
        for (let i = 0; i < leads.length; i++) {
          if (leads[i].followup[leads[i].followup.length - 1]) {
            if (
              leads[i].followup[leads[i].followup.length - 1].status ==
              'APPROVED'
            ) {
              membersList.push(leads[i]);
            }
          }
        }
        // console.log(membersList);
        res.status(200).json({
          success: true,
          msg: 'Member Lists are fetched',
          members: membersList
        });
      }
    });
  }
);

// getting leads by category
router.get(
  '/getNewLeads',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    Lead.getNewLeads((err, newleads) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'Failed to fetch new leads', err: err });
      } else {
        res.status(200).json({
          success: true,
          msg: 'new leads fetched',
          newleads: newleads
        });
      }
    });
  }
);
router.get(
  '/getNewLeads/:username',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    Lead.getNewLeadsByUser(req.params.username, (err, newleads) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'Failed to fetch new leads', err: err });
      } else {
        res.status(200).json({
          success: true,
          msg: 'new leads fetched',
          newleads: newleads
        });
      }
    });
  }
);

router.get(
  '/getNPC',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    Lead.getOldLeads((err, oldleads) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'Failed to fetch NPC leads', err: err });
      } else {
        let oldLeadsArray = [];
        for (let i = 0; i < oldleads.length; i++) {
          if (oldleads[i].followup.length) {
            if (
              oldleads[i].followup[oldleads[i].followup.length - 1].status ==
                'NPC'
            ) {
              oldLeadsArray.push(oldleads[i]);
            } else {
            }
          }
        }

        res.status(200).json({
          success: true,
          msg: 'NPC leads fetched',
          NPC: oldLeadsArray
        });
      }
    });
  }
);
router.get(
  '/getNPC/:username',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    Lead.getOldLeadsByUser(req.params.username, (err, oldleads) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'Failed to fetch NPC leads', err: err });
      } else {
        let oldLeadsArray = [];
        for (let i = 0; i < oldleads.length; i++) {
          if (oldleads[i].followup.length) {
            if (
              oldleads[i].followup[oldleads[i].followup.length - 1].status ==
                'NPC'
            ) {
              oldLeadsArray.push(oldleads[i]);
            } else {
            }
          }
        }

        res.status(200).json({
          success: true,
          msg: 'NPC leads fetched',
          NPC: oldLeadsArray
        });
      }
    });
  }
);

router.get(
  '/getInterested',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    Lead.getOldLeads((err, oldleads) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'Failed to fetch Interested leads', err: err });
      } else {
        let oldLeadsArray = [];
        for (let i = 0; i < oldleads.length; i++) {
          if (oldleads[i].followup.length) {
            if (
              oldleads[i].followup[oldleads[i].followup.length - 1].status ==
                'INTERESTED'
            ) {
              oldLeadsArray.push(oldleads[i]);
            } else {
            }
          }
        }

        res.status(200).json({
          success: true,
          msg: 'Interested leads fetched',
          interested: oldLeadsArray
        });
      }
    });
  }
);
router.get(
  '/getInterested/:username',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    Lead.getOldLeadsByUser(req.params.username, (err, oldleads) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'Failed to fetch Interested leads', err: err });
      } else {
        let oldLeadsArray = [];
        for (let i = 0; i < oldleads.length; i++) {
          if (oldleads[i].followup.length) {
            if (
              oldleads[i].followup[oldleads[i].followup.length - 1].status ==
                'INTERESTED'
            ) {
              oldLeadsArray.push(oldleads[i]);
            } else {
            }
          }
        }

        res.status(200).json({
          success: true,
          msg: 'Interested leads fetched',
          interested: oldLeadsArray
        });
      }
    });
  }
);

router.get(
  '/getProspects',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    Lead.getOldLeads((err, oldleads) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'Failed to fetch Prospect leads', err: err });
      } else {
        let oldLeadsArray = [];
        for (let i = 0; i < oldleads.length; i++) {
          if (oldleads[i].followup.length) {
            if (
              oldleads[i].followup[oldleads[i].followup.length - 1].status ==
                'PROSPECT'
            ) {
              oldLeadsArray.push(oldleads[i]);
            } else {
            }
          }
        }

        res.status(200).json({
          success: true,
          msg: 'Prospect leads fetched',
          prospects: oldLeadsArray
        });
      }
    });
  }
);
router.get(
  '/getProspects/:username',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    Lead.getOldLeadsByUser(req.params.username, (err, oldleads) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'Failed to fetch Prospect leads', err: err });
      } else {
        let oldLeadsArray = [];
        for (let i = 0; i < oldleads.length; i++) {
          if (oldleads[i].followup.length) {
            if (
              oldleads[i].followup[oldleads[i].followup.length - 1].status ==
                'PROSPECT'
            ) {
              oldLeadsArray.push(oldleads[i]);
            } else {
            }
          }
        }

        res.status(200).json({
          success: true,
          msg: 'Prospect leads fetched',
          prospects: oldLeadsArray
        });
      }
    });
  }
);

router.get(
  '/getOldLeads',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    Lead.getOldLeads((err, oldleads) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'Failed to fetch old leads', err: err });
      } else {
        let oldLeadsArray = [];
        for (let i = 0; i < oldleads.length; i++) {
          if (oldleads[i].followup.length) {
            if (
              oldleads[i].followup[oldleads[i].followup.length - 1].status ==
                'APPROVED' ||
              oldleads[i].followup[oldleads[i].followup.length - 1].status ==
                'CLOSED'
            ) {
            } else {
              oldLeadsArray.push(oldleads[i]);
            }
          }
        }

        res.status(200).json({
          success: true,
          msg: 'old leads fetched',
          oldleads: oldLeadsArray
        });
      }
    });
  }
);
router.get(
  '/getOldLeads/:username',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    Lead.getOldLeadsByUser(req.params.username, (err, oldleads) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'Failed to fetch old leads', err: err });
      } else {
        let oldLeadsArray = [];
        for (let i = 0; i < oldleads.length; i++) {
          if (oldleads[i].followup.length) {
            if (
              oldleads[i].followup[oldleads[i].followup.length - 1].status ==
                'APPROVED' ||
              oldleads[i].followup[oldleads[i].followup.length - 1].status ==
                'CLOSED'
            ) {
            } else {
              oldLeadsArray.push(oldleads[i]);
            }
          }
        }

        res.status(200).json({
          success: true,
          msg: 'old leads fetched',
          oldleads: oldLeadsArray
        });
      }
    });
  }
);

router.get(
  '/getCallbackLeads',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    callbackLeads = [];
    Lead.getLeads((err, leads) => {
      if (err) {
        res.status(200).json({
          success: false,
          msg: 'Failed to fetch callback leads',
          err: err
        });
      } else {
        for (let i = 0; i < leads.length; i++) {
          if (leads[i].followup[leads[i].followup.length - 1]) {
            if (
              leads[i].followup[leads[i].followup.length - 1].status ==
              'CALLBACK'
            ) {
              callbackLeads.push(leads[i]);
            }
          }
        }
        res.status(200).json({
          success: true,
          msg: 'callback leads are fetched',
          leads: callbackLeads
        });
      }
    });
  }
);
router.get(
  '/getCallbackLeads/:username',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    callbackLeads = [];
    Lead.getLeadsByUser(req.params.username, (err, leads) => {
      if (err) {
        res.status(200).json({
          success: false,
          msg: 'Failed to fetch callback leads',
          err: err
        });
      } else {
        for (let i = 0; i < leads.length; i++) {
          if (leads[i].followup[leads[i].followup.length - 1]) {
            if (
              leads[i].followup[leads[i].followup.length - 1].status ==
              'CALLBACK'
            ) {
              callbackLeads.push(leads[i]);
            }
          }
        }
        res.status(200).json({
          success: true,
          msg: 'callback leads are fetched',
          leads: callbackLeads
        });
      }
    });
  }
);

router.get(
  '/getApprovedLeads',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    approvedLeads = [];
    Lead.getLeads((err, leads) => {
      if (err) {
        res.status(200).json({
          success: false,
          msg: 'Failed to fetch approved leads',
          err: err
        });
      } else {
        for (let i = 0; i < leads.length; i++) {
          if (leads[i].followup[leads[i].followup.length - 1]) {
            if (
              leads[i].followup[leads[i].followup.length - 1].status ==
              'APPROVED'
            ) {
              approvedLeads.push(leads[i]);
            }
          }
        }
        res.status(200).json({
          success: true,
          msg: 'approved leads are fetched',
          leads: approvedLeads
        });
      }
    });
  }
);
router.get(
  '/getApprovedLeads/:username',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    approvedLeads = [];
    Lead.getLeadsByUser(req.params.username, (err, leads) => {
      if (err) {
        res.status(200).json({
          success: false,
          msg: 'Failed to fetch approved leads',
          err: err
        });
      } else {
        for (let i = 0; i < leads.length; i++) {
          if (leads[i].followup[leads[i].followup.length - 1]) {
            if (
              leads[i].followup[leads[i].followup.length - 1].status ==
              'APPROVED'
            ) {
              approvedLeads.push(leads[i]);
            }
          }
        }
        res.status(200).json({
          success: true,
          msg: 'approved leads are fetched',
          leads: approvedLeads
        });
      }
    });
  }
);

router.get(
  '/getClosedLeads',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    closedLeads = [];
    Lead.getLeads((err, leads) => {
      if (err) {
        res.status(200).json({
          success: false,
          msg: 'Failed to fetch closed leads',
          err: err
        });
      } else {
        for (let i = 0; i < leads.length; i++) {
          if (leads[i].followup[leads[i].followup.length - 1]) {
            if (
              leads[i].followup[leads[i].followup.length - 1].status == 'CLOSED'
            ) {
              closedLeads.push(leads[i]);
            }
          }
        }
        res.status(200).json({
          success: true,
          msg: 'closed leads are fetched',
          leads: closedLeads
        });
      }
    });
  }
);
router.get(
  '/getClosedLeads/:username',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    closedLeads = [];
    Lead.getLeadsByUser(req.params.username, (err, leads) => {
      if (err) {
        res.status(200).json({
          success: false,
          msg: 'Failed to fetch closed leads',
          err: err
        });
      } else {
        for (let i = 0; i < leads.length; i++) {
          if (leads[i].followup[leads[i].followup.length - 1]) {
            if (
              leads[i].followup[leads[i].followup.length - 1].status == 'CLOSED'
            ) {
              closedLeads.push(leads[i]);
            }
          }
        }
        res.status(200).json({
          success: true,
          msg: 'closed leads are fetched',
          leads: closedLeads
        });
      }
    });
  }
);

// end getting leads

// counting routes
router.get(
  '/getCallbackLeadsCount',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    let callbackcount = 0;
    Lead.getLeads((err, leads) => {
      if (err) {
        res.status(200).json({
          success: false,
          msg: 'Failed to fetch callback count',
          err: err
        });
      } else {
        for (let i = 0; i < leads.length; i++) {
          if (leads[i].followup[leads[i].followup.length - 1]) {
            if (
              leads[i].followup[leads[i].followup.length - 1].status ==
              'CALLBACK'
            ) {
              callbackcount++;
            }
          }
        }
        res.status(200).json({
          success: true,
          msg: 'callback leads counts fetched ',
          count: callbackcount
        });
      }
    });
  }
);
router.get(
  '/getCallbackLeadsCount/:username',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    let callbackcount = 0;
    Lead.getLeadsByUser(req.params.username, (err, leads) => {
      if (err) {
        res.status(200).json({
          success: false,
          msg: 'Failed to fetch callback count',
          err: err
        });
      } else {
        for (let i = 0; i < leads.length; i++) {
          if (leads[i].followup[leads[i].followup.length - 1]) {
            if (
              leads[i].followup[leads[i].followup.length - 1].status ==
              'CALLBACK'
            ) {
              callbackcount++;
            }
          }
        }
        res.status(200).json({
          success: true,
          msg: 'callback leads counts fetched ',
          count: callbackcount
        });
      }
    });
  }
);


router.get(
  '/getNPCCount',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    let callbackcount = 0;
    Lead.getLeads((err, leads) => {
      if (err) {
        res.status(200).json({
          success: false,
          msg: 'Failed to fetch NPC count',
          err: err
        });
      } else {
        for (let i = 0; i < leads.length; i++) {
          if (leads[i].followup[leads[i].followup.length - 1]) {
            if (
              leads[i].followup[leads[i].followup.length - 1].status ==
              'NPC'
            ) {
              callbackcount++;
            }
          }
        }
        res.status(200).json({
          success: true,
          msg: 'NPC leads counts fetched ',
          count: callbackcount
        });
      }
    });
  }
);
router.get(
  '/getNPCCount/:username',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    let callbackcount = 0;
    Lead.getLeadsByUser(req.params.username, (err, leads) => {
      if (err) {
        res.status(200).json({
          success: false,
          msg: 'Failed to fetch NPC count',
          err: err
        });
      } else {
        for (let i = 0; i < leads.length; i++) {
          if (leads[i].followup[leads[i].followup.length - 1]) {
            if (
              leads[i].followup[leads[i].followup.length - 1].status ==
              'NPC'
            ) {
              callbackcount++;
            }
          }
        }
        res.status(200).json({
          success: true,
          msg: 'NPC leads counts fetched ',
          count: callbackcount
        });
      }
    });
  }
);


router.get(
  '/getInterestedCount',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    let intcount = 0;
    Lead.getLeads((err, leads) => {
      if (err) {
        res.status(200).json({
          success: false,
          msg: 'Failed to fetch Interested count',
          err: err
        });
      } else {
        for (let i = 0; i < leads.length; i++) {
          if (leads[i].followup[leads[i].followup.length - 1]) {
            if (
              leads[i].followup[leads[i].followup.length - 1].status ==
              'INTERESTED'
            ) {
              intcount++;
            }
          }
        }
        res.status(200).json({
          success: true,
          msg: 'Interested leads counts fetched ',
          count: intcount
        });
      }
    });
  }
);
router.get(
  '/getInterestedCount/:username',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    let intcount = 0;
    Lead.getLeadsByUser(req.params.username, (err, leads) => {
      if (err) {
        res.status(200).json({
          success: false,
          msg: 'Failed to fetch Interested count',
          err: err
        });
      } else {
        for (let i = 0; i < leads.length; i++) {
          if (leads[i].followup[leads[i].followup.length - 1]) {
            if (
              leads[i].followup[leads[i].followup.length - 1].status ==
              'INTERESTED'
            ) {
              intcount++;
            }
          }
        }
        res.status(200).json({
          success: true,
          msg: 'Interested leads counts fetched ',
          count: intcount
        });
      }
    });
  }
);


router.get(
  '/getProspectsCount',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    let pcount = 0;
    Lead.getLeads((err, leads) => {
      if (err) {
        res.status(200).json({
          success: false,
          msg: 'Failed to fetch Prospect count',
          err: err
        });
      } else {
        for (let i = 0; i < leads.length; i++) {
          if (leads[i].followup[leads[i].followup.length - 1]) {
            if (
              leads[i].followup[leads[i].followup.length - 1].status ==
              'PROSPECT'
            ) {
              pcount++;
            }
          }
        }
        res.status(200).json({
          success: true,
          msg: 'Prospect leads counts fetched ',
          count: pcount
        });
      }
    });
  }
);
router.get(
  '/getProspectsCount/:username',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    let pcount = 0;
    Lead.getLeadsByUser(req.params.username, (err, leads) => {
      if (err) {
        res.status(200).json({
          success: false,
          msg: 'Failed to fetch Prospect count',
          err: err
        });
      } else {
        for (let i = 0; i < leads.length; i++) {
          if (leads[i].followup[leads[i].followup.length - 1]) {
            if (
              leads[i].followup[leads[i].followup.length - 1].status ==
              'PROSPECT'
            ) {
              pcount++;
            }
          }
        }
        res.status(200).json({
          success: true,
          msg: 'Prospect leads counts fetched ',
          count: pcount
        });
      }
    });
  }
);

router.get(
  '/getClosedLeadsCount',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    let closedleadcount = 0;
    Lead.getLeads((err, leads) => {
      if (err) {
        res.status(200).json({
          success: false,
          msg: 'Failed to fetch callback count',
          err: err
        });
      } else {
        for (let i = 0; i < leads.length; i++) {
          if (leads[i].followup[leads[i].followup.length - 1]) {
            if (
              leads[i].followup[leads[i].followup.length - 1].status == 'CLOSED'
            ) {
              closedleadcount++;
            }
          }
        }
        res.status(200).json({
          success: true,
          msg: 'closed leads counts fetched ',
          count: closedleadcount
        });
      }
    });
  }
);
router.get(
  '/getClosedLeadsCount/:username',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    let closedleadcount = 0;
    Lead.getLeadsByUser(req.params.username, (err, leads) => {
      if (err) {
        res.status(200).json({
          success: false,
          msg: 'Failed to fetch callback count',
          err: err
        });
      } else {
        for (let i = 0; i < leads.length; i++) {
          if (leads[i].followup[leads[i].followup.length - 1]) {
            if (
              leads[i].followup[leads[i].followup.length - 1].status == 'CLOSED'
            ) {
              closedleadcount++;
            }
          }
        }
        res.status(200).json({
          success: true,
          msg: 'closed leads counts fetched ',
          count: closedleadcount
        });
      }
    });
  }
);

router.get(
  '/getApprovedLeadsCount',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    let approvedLeadsCount = 0;
    Lead.getLeads((err, leads) => {
      if (err) {
        res.status(200).json({
          success: false,
          msg: 'Failed to fetch approved count',
          err: err
        });
      } else {
        for (let i = 0; i < leads.length; i++) {
          if (leads[i].followup[leads[i].followup.length - 1]) {
            if (
              leads[i].followup[leads[i].followup.length - 1].status ==
              'APPROVED'
            ) {
              approvedLeadsCount++;
            }
          }
        }
        res.status(200).json({
          success: true,
          msg: 'approved leads counts fetched ',
          count: approvedLeadsCount
        });
      }
    });
  }
);
router.get(
  '/getApprovedLeadsCount/:username',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    approvedLeadsCount = 0;
    Lead.getLeadsByUser(req.params.username, (err, leads) => {
      if (err) {
        res.status(200).json({
          success: false,
          msg: 'Failed to fetch approved count',
          err: err
        });
      } else {
        for (let i = 0; i < leads.length; i++) {
          if (leads[i].followup[leads[i].followup.length - 1]) {
            if (
              leads[i].followup[leads[i].followup.length - 1].status ==
              'APPROVED'
            ) {
              approvedLeadsCount++;
            }
          }
        }
        res.status(200).json({
          success: true,
          msg: 'approved leads counts fetched ',
          count: approvedLeadsCount
        });
      }
    });
  }
);

router.get(
  '/getNewLeadsCount',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    Lead.getNewLeads((err, newleads) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'Failed to fetch new leads', err: err });
      } else {
        res.status(200).json({
          success: true,
          msg: 'new leads count fetched',
          count: newleads.length
        });
      }
    });
  }
);
router.get(
  '/getNewLeadsCount/:username',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    Lead.getNewLeadsByUser(req.params.username, (err, newleads) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'Failed to fetch new leads', err: err });
      } else {
        res.status(200).json({
          success: true,
          msg: 'new leads count fetched',
          count: newleads.length
        });
      }
    });
  }
);

router.get(
  '/getOldLeadsCount',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    Lead.getOldLeads((err, oldleads) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'Failed to fetch old leads', err: err });
      } else {
        let oldLeadsArray = [];
        for (let i = 0; i < oldleads.length; i++) {
          if (oldleads[i].followup.length) {
            if (
              oldleads[i].followup[oldleads[i].followup.length - 1].status ==
                'APPROVED' ||
              oldleads[i].followup[oldleads[i].followup.length - 1].status ==
                'CLOSED'
            ) {
            } else {
              oldLeadsArray.push(oldleads[i]);
            }
          }
        }
        res.status(200).json({
          success: true,
          msg: 'old leads count fetched',
          count: oldLeadsArray.length
        });
      }
    });
  }
);
router.get(
  '/getOldLeadsCount/:username',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    Lead.getOldLeadsByUser(req.params.username, (err, oldleads) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'Failed to fetch old leads', err: err });
      } else {
        let oldLeadsArray = [];
        for (let i = 0; i < oldleads.length; i++) {
          if (oldleads[i].followup.length) {
            if (
              oldleads[i].followup[oldleads[i].followup.length - 1].status ==
                'APPROVED' ||
              oldleads[i].followup[oldleads[i].followup.length - 1].status ==
                'CLOSED'
            ) {
            } else {
              oldLeadsArray.push(oldleads[i]);
            }
          }
        }
        res.status(200).json({
          success: true,
          msg: 'old leads count fetched',
          count: oldLeadsArray.length
        });
      }
    });
  }
);

router.post('/import', (req, res) => {
  console.log('import');
  new formidable.IncomingForm().parse(req)
    .on('field', (name, field) => {
      console.log('Field', name, field)
    })
    .on('file', (name, file) => {
      console.log('Uploaded file', name, file)
    })
    .on('aborted', () => {
      console.error('Request aborted by the user')
    })
    .on('error', (err) => {
      console.error('Error', err)
      throw err
    })
    .on('end', () => {
      res.end()
    })
});


//get new Lead count
router.get(
  '/getLeadsCount',
  // passport.authenticate('jwt', { session: false }),
  (req, res) => {  
    Lead.getLeadsCount((err, lead) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'error occured', err: err });
      } else {
        res
          .status(200)
          .json({ success: true, msg: 'Lead Count Completed', lead: lead });
      }
    });
  }
);


//get Old Lead count
router.get(
  '/getOldLeadsCounter',
  // passport.authenticate('jwt', { session: false }),
  (req, res) => {  
    Lead.getOldLeadsCount((err, lead) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'error occured', err: err });
      } else {
        res
          .status(200)
          .json({ success: true, msg: 'Old Lead Count Completed', lead: lead });
      }
    });
  }
);


module.exports = router;
